package com.huiju.estateagents.miniPackage.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.miniPackage.entity.SysVipPackageMain;
import com.huiju.estateagents.miniPackage.service.ISysVipPackageMainService;

/**
 * <p>
    * 会员套餐说明  前端控制器
    * </p>
 *
 * @author wxx
 * @since 2020-06-16
 */
@RestController
@RequestMapping("/api")
public class SysVipPackageMainController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysVipPackageMainController.class);

    @Autowired
    public ISysVipPackageMainService iSysVipPackageMainService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/sysVipPackageMain",method= RequestMethod.GET)
    public ResponseBean sysVipPackageMainList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                              @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SysVipPackageMain> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<SysVipPackageMain> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<SysVipPackageMain> result = iSysVipPackageMainService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageMainList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param sysVipPackageMain 实体对象
     * @return
     */
    @RequestMapping(value="/sysVipPackageMain",method= RequestMethod.POST)
    public ResponseBean sysVipPackageMainAdd(@RequestBody SysVipPackageMain sysVipPackageMain){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysVipPackageMainService.save(sysVipPackageMain)){
                responseBean.addSuccess(sysVipPackageMain);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageMainAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/sysVipPackageMain/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysVipPackageMainDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSysVipPackageMainService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageMainDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysVipPackageMain 实体对象
     * @return
     */
    @RequestMapping(value="/sysVipPackageMain/{id}",method= RequestMethod.PUT)
    public ResponseBean sysVipPackageMainUpdate(@PathVariable Integer id,
                                        @RequestBody SysVipPackageMain sysVipPackageMain){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysVipPackageMainService.updateById(sysVipPackageMain)){
                responseBean.addSuccess(sysVipPackageMain);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageMainUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysVipPackageMain/{id}",method= RequestMethod.GET)
    public ResponseBean sysVipPackageMainGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSysVipPackageMainService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageMainDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
