package com.huiju.estateagents.miniPackage.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.miniPackage.entity.TaUserPackages;
import com.huiju.estateagents.miniPackage.service.ITaUserPackagesService;

/**
 * <p>
    * 会员套餐记录  前端控制器
    * </p>
 *
 * @author wxx
 * @since 2020-06-16
 */
@RestController
@RequestMapping("/api")
public class TaUserPackagesController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaUserPackagesController.class);

    @Autowired
    public ITaUserPackagesService iTaUserPackagesService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taUserPackages",method= RequestMethod.GET)
    public ResponseBean taUserPackagesList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaUserPackages> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaUserPackages> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaUserPackages> result = iTaUserPackagesService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserPackagesList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taUserPackages 实体对象
     * @return
     */
    @RequestMapping(value="/taUserPackages",method= RequestMethod.POST)
    public ResponseBean taUserPackagesAdd(@RequestBody TaUserPackages taUserPackages){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaUserPackagesService.save(taUserPackages)){
                responseBean.addSuccess(taUserPackages);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserPackagesAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taUserPackages/{id}", method= RequestMethod.DELETE)
    public ResponseBean taUserPackagesDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaUserPackagesService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserPackagesDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taUserPackages 实体对象
     * @return
     */
    @RequestMapping(value="/taUserPackages/{id}",method= RequestMethod.PUT)
    public ResponseBean taUserPackagesUpdate(@PathVariable Integer id,
                                        @RequestBody TaUserPackages taUserPackages){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaUserPackagesService.updateById(taUserPackages)){
                responseBean.addSuccess(taUserPackages);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserPackagesUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taUserPackages/{id}",method= RequestMethod.GET)
    public ResponseBean taUserPackagesGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaUserPackagesService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserPackagesDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
